"""
INCV Project
--------
This package validates the national code of Iranians
"""

__author__ = 'Majid Azizian'
__email__ = "azizian.majid@gmail.com"
__version__ = '0.1.0'
from .NationalCodeValidation import CodeValidation