from setuptools import setup

setup(name="INCV",
      license='MIT',
      version="0.1.1",
      description="This package validates the national code of Iranians",
      author="Majid Azizian",
      author_email='your.email@domain.com',
      url='https://github.com/majidazizian/incv',
      packages=["INCV"]
      )
